@@ -51,7 +51,7 @@
 #include <QLabel>
 #include <QMenu>
 #include <QApplication>
-#include <QDesktopWidget>
+#include <QScreen>
 #include <QSvgGenerator>
 #include <QWidgetAction>
 #include <QFileDialog>
@@ -72,11 +72,11 @@ class TimeAxis : public CartesianAxis
 {
     Q_OBJECT
 public:
-    explicit TimeAxis(AbstractCartesianDiagram* diagram = 0)
+    explicit TimeAxis(AbstractCartesianDiagram* diagram = nullptr)
         : CartesianAxis(diagram)
     {}
 
-    virtual const QString customizedLabel(const QString& label) const
+    const QString customizedLabel(const QString& label) const override
     {
         // squeeze large numbers here
         // TODO: when the unit is 'b' also use prettyCost() here
@@ -88,11 +88,11 @@ class SizeAxis : public CartesianAxis
 {
     Q_OBJECT
 public:
-    explicit SizeAxis(AbstractCartesianDiagram* diagram = 0)
+    explicit SizeAxis(AbstractCartesianDiagram* diagram = nullptr)
         : CartesianAxis(diagram)
     {}
 
-    virtual const QString customizedLabel(const QString& label) const
+    const QString customizedLabel(const QString& label) const override
     {
         // TODO: change distance between labels to 1024 and simply use prettyCost() here
         KFormat format(QLocale::system());
@@ -149,24 +149,25 @@ ChartTab::ChartTab(const FileData* data,
   : DocumentTabInterface(data, guiParent, parent)
     , m_chart(new Chart(this))
     , m_header(new QLabel(this))
-    , m_totalDiagram(0)
+    , m_totalDiagram(nullptr)
     , m_totalCostModel(new TotalCostModel(m_chart))
-    , m_detailedDiagram(0)
+    , m_detailedDiagram(nullptr)
     , m_detailedCostModel(new DetailedCostModel(m_chart))
     , m_legend(new Legend(m_chart))
-    , m_print(0)
-    , m_saveAs(0)
-    , m_toggleTotal(0)
-    , m_toggleDetailed(0)
-    , m_hideFunction(0)
-    , m_hideOtherFunctions(0)
+    , m_print(nullptr)
+    , m_saveAs(nullptr)
+    , m_toggleTotal(nullptr)
+    , m_toggleDetailed(nullptr)
+    , m_hideFunction(nullptr)
+    , m_hideOtherFunctions(nullptr)
     , m_box(new QSpinBox(this))
     , m_settingSelection(false)
 {
     setXMLFile(QStringLiteral("charttabui.rc"), true);
     setupActions();
 
-    setLayout(new QVBoxLayout(this));
+    auto *layout =  new QVBoxLayout(this);
+    layout->setContentsMargins({});
 
     setupGui();
 }
@@ -177,19 +178,19 @@ ChartTab::~ChartTab()
 
 void ChartTab::setupActions()
 {
-    m_print = KStandardAction::print(this, SLOT(showPrintPreviewDialog()), actionCollection());
+    m_print = KStandardAction::print(this, &ChartTab::showPrintPreviewDialog, actionCollection());
     actionCollection()->addAction(QStringLiteral("file_print"), m_print);
 
-    m_saveAs = KStandardAction::saveAs(this, SLOT(saveCurrentDocument()), actionCollection());
+    m_saveAs = KStandardAction::saveAs(this, &ChartTab::saveCurrentDocument, actionCollection());
     actionCollection()->addAction(QStringLiteral("file_save_as"), m_saveAs);
 
-    m_toggleTotal = new QAction(QIcon::fromTheme(QStringLiteral("office-chart-area")), i18n("Toggle total cost graph"), actionCollection());
+    m_toggleTotal = new QAction(QIcon::fromTheme(QStringLiteral("office-chart-area")), i18nc("@action", "Toggle Total Cost Graph"), actionCollection());
     m_toggleTotal->setCheckable(true);
     m_toggleTotal->setChecked(true);
     connect(m_toggleTotal, &QAction::toggled, this, &ChartTab::showTotalGraph);
     actionCollection()->addAction(QStringLiteral("toggle_total"), m_toggleTotal);
 
-    m_toggleDetailed = new QAction(QIcon::fromTheme(QStringLiteral("office-chart-area-stacked")), i18n("Toggle detailed cost graph"), actionCollection());
+    m_toggleDetailed = new QAction(QIcon::fromTheme(QStringLiteral("office-chart-area-stacked")), i18nc("@action", "Toggle Detailed Cost Graph"), actionCollection());
     m_toggleDetailed->setCheckable(true);
     m_toggleDetailed->setChecked(true);
     connect(m_toggleDetailed, &QAction::toggled, this, &ChartTab::showDetailedGraph);
@@ -200,7 +201,7 @@ void ChartTab::setupActions()
     stackNumAction->setText(i18n("Stacked diagrams"));
     QWidget *stackNumWidget = new QWidget;
     QHBoxLayout* stackNumLayout = new QHBoxLayout;
-    stackNumLayout->addWidget(new QLabel(i18n("Stacked diagrams:")));
+    stackNumLayout->addWidget(new QLabel(i18nc("@label:spinbox", "Stacked diagrams:")));
     m_box->setMinimum(0);
     m_box->setMaximum(50);
     m_box->setValue(10);
@@ -209,10 +210,10 @@ void ChartTab::setupActions()
     stackNumWidget->setLayout(stackNumLayout);
     stackNumAction->setDefaultWidget(stackNumWidget);
 
-    m_hideFunction = new QAction(i18n("hide function"), this);
+    m_hideFunction = new QAction(i18nc("@action", "Hide Function"), this);
     connect(m_hideFunction, &QAction::triggered,
             this, &ChartTab::slotHideFunction);
-    m_hideOtherFunctions = new QAction(i18n("hide other functions"), this);
+    m_hideOtherFunctions = new QAction(i18nc("@action", "Hide Other Functions"), this);
     connect(m_hideOtherFunctions, &QAction::triggered,
             this, &ChartTab::slotHideOtherFunctions);
 }
@@ -224,7 +225,7 @@ void ChartTab::setupGui()
 
     // HACK: otherwise the legend becomes _really_ large and might even crash X...
     // to visualize the issue, try: m_chart->setMaximumSize(QSize(10000, 10000));
-    m_chart->setMaximumSize(qApp->desktop()->size());
+    m_chart->setMaximumSize(qApp->primaryScreen()->geometry().size());
 
     // for axis labels to fit
     m_chart->setGlobalLeadingRight(10);
@@ -407,7 +408,7 @@ void ChartTab::updateLegendPosition()
             break;
         default:
             align = Qt::AlignHCenter | Qt::AlignVCenter;
-            qDebug() << "invalid legend alignmemnt";
+            qDebug() << "invalid legend alignment";
     }
 
     // do something reasonable since top,bottom have no effect
@@ -451,7 +452,7 @@ void ChartTab::updateDetailedPeaks()
 
 void ChartTab::updateHeader()
 {
-    const QString app = m_data->cmd().split(QLatin1Char(' '), QString::SkipEmptyParts).first();
+    const QString app = m_data->cmd().split(QLatin1Char(' '), Qt::SkipEmptyParts).first();
 
     m_header->setText(QString::fromLatin1("<b>%1</b><br /><i>%2</i>")
                         .arg(i18n("Memory consumption of %1", app))
@@ -462,7 +463,8 @@ void ChartTab::updateHeader()
 
 void ChartTab::saveCurrentDocument()
 {
-    const auto saveFilename = QFileDialog::getSaveFileName(this, i18n("Save Current Visualization"), QString(),
+    const auto saveFilename = QFileDialog::getSaveFileName(this, i18nc("@title:window", "Save Current Visualization"),
+                                                           QString(),
                                                            i18n("Images (*.png *.jpg *.tiff *.svg)"));
 
     if (!saveFilename.isEmpty()) {
@@ -485,11 +487,9 @@ void ChartTab::saveCurrentDocument()
         }
 
         // Other format
-        else if (!QPixmap::grabWidget(m_chart).save(saveFilename)) {
+        else if (!m_chart->grab().save(saveFilename)) {
 
-            KMessageBox::sorry(this, QString(
-                i18n("Error, failed to save the image to %1.")
-                    ).arg(saveFilename));
+            KMessageBox::error(this, i18n("Failed to save the image to %1.", saveFilename));
         }
     }
 }
@@ -500,7 +500,7 @@ void ChartTab::showPrintPreviewDialog()
     QPrintPreviewDialog *ppd = new QPrintPreviewDialog(&printer, this);
     ppd->setAttribute(Qt::WA_DeleteOnClose);
     connect(ppd, &QPrintPreviewDialog::paintRequested, this, &ChartTab::printFile);
-    ppd->setWindowTitle(i18n("Massif Chart Print Preview"));
+    ppd->setWindowTitle(i18nc("@title:window", "Massif Chart Print Preview"));
     ppd->resize(800, 600);
     ppd->exec();
 }
@@ -509,7 +509,7 @@ void ChartTab::printFile(QPrinter *printer)
 {
     QPainter painter;
     painter.begin(printer);
-    m_chart->paint(&painter, printer->pageRect());
+    m_chart->paint(&painter, printer->pageLayout().paintRectPixels(printer->resolution()));
     painter.end();
 }
 
@@ -619,3 +619,5 @@ void ChartTab::selectModelItem(const ModelItem& item)
 }
 
 #include "charttab.moc"
+
+#include "moc_charttab.cpp"
