@@ -23,10 +23,11 @@
 #ifndef MASSIF_PARSERPRIVATE_H
 #define MASSIF_PARSERPRIVATE_H
 
-#include <QtCore/QByteArray>
-#include <QtCore/QStringList>
-#include <QtCore/QSet>
-#include <QVector>
+#include <QByteArray>
+#include <QStringList>
+#include <QRegExp>
+#include <QSet>
+#include <QList>
 
 class QIODevice;
 
@@ -122,8 +123,8 @@ private:
     bool m_hadCustomAllocators;
 
     /// list of custom allocator wildcards
-    QVector<QRegExp> m_allocators;
-    QVector<QByteArray> m_plainAllocators;
+    QList<QRegExp> m_allocators;
+    QList<QByteArray> m_plainAllocators;
 
     /// improve memory consumption by re-using known labels
     /// and making use of the implicit sharing of QByteArrays
