@@ -41,20 +41,20 @@ public:
      * Generates a Dot graph file representing @p snapshot
      * and writes it to a temporary file.
      */
-    DotGraphGenerator(const SnapshotItem* snapshot, const QString& timeUnit, QObject* parent = 0);
+    DotGraphGenerator(const SnapshotItem* snapshot, const QString& timeUnit, QObject* parent = nullptr);
     /**
      * Generates a Dot graph file representing @p node
      * and writes it to a temporary file.
      */
-    DotGraphGenerator(const TreeLeafItem* node, const QString& timeUnit, QObject* parent = 0);
-    ~DotGraphGenerator();
+    DotGraphGenerator(const TreeLeafItem* node, const QString& timeUnit, QObject* parent = nullptr);
+    ~DotGraphGenerator() override;
 
     /**
      * Stops generating the Dot graph file and deletes the temp file.
      */
     void cancel();
 
-    virtual void run();
+    void run() override;
     /**
      * @return A path to the generated Dot graph file. Path might be empty if errors occurred.
      */
