@@ -24,14 +24,17 @@
 #define MASSIF_MODEL_ITEM_H
 
 #include <QPair>
+#include <QMetaType>
+
+#include "treeleafitem.h"
+#include "snapshotitem.h"
 
 namespace Massif {
 
-class TreeLeafItem;
-class SnapshotItem;
-
 typedef QPair<const TreeLeafItem*, const SnapshotItem*> ModelItem;
 
 }
 
+Q_DECLARE_METATYPE(Massif::ModelItem)
+
 #endif // MODEL_ITEM_H
